summaryrefslogtreecommitdiffstats
path: root/kmail/imapaccountbase.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/imapaccountbase.cpp')
-rw-r--r--kmail/imapaccountbase.cpp42
1 files changed, 21 insertions, 21 deletions
diff --git a/kmail/imapaccountbase.cpp b/kmail/imapaccountbase.cpp
index b0f78c5a..01e1324c 100644
--- a/kmail/imapaccountbase.cpp
+++ b/kmail/imapaccountbase.cpp
@@ -32,7 +32,7 @@ using KMail::SieveConfig;
using KMail::AccountManager;
#include "kmfolder.h"
#include "broadcaststatus.h"
-using KPIM::BroadcastStatus;
+using KPIM::BroadcasStatus;
#include "kmmainwin.h"
#include "kmfolderimap.h"
#include "kmmainwidget.h"
@@ -354,7 +354,7 @@ namespace KMail {
checkDone( false, CheckOK );
}
if ( showStatusMsg )
- BroadcastStatus::instance()->setStatusMsgTransmissionCompleted(
+ BroadcasStatus::instance()->seStatusMsgTransmissionCompleted(
name(), newMails);
}
@@ -669,7 +669,7 @@ namespace KMail {
// split, allow empty parts as we can get empty namespaces
TQStringList parts = TQStringList::split( "=", *it, true );
imapNamespace section = imapNamespace( parts[0].toInt() );
- if ( map.contains( section ) ) {
+ if ( map.tqcontains( section ) ) {
nsDelim = map[section];
} else {
nsDelim.clear();
@@ -736,31 +736,31 @@ namespace KMail {
TQString msg = i18n("KMail has detected a prefix entry in the "
"configuration of the account \"%1\" which is obsolete with the "
"support of IMAP namespaces.").arg( name() );
- if ( list.contains( "" ) ) {
- // replace empty entry with the old prefix
+ if ( list.tqcontains( "" ) ) {
+ // tqreplace empty entry with the old prefix
list.remove( "" );
list += mOldPrefix;
mNamespaces[PersonalNS] = list;
- if ( mNamespaceToDelimiter.contains( "" ) ) {
+ if ( mNamespaceToDelimiter.tqcontains( "" ) ) {
TQString delim = mNamespaceToDelimiter[""];
mNamespaceToDelimiter.remove( "" );
mNamespaceToDelimiter[mOldPrefix] = delim;
}
- kdDebug(5006) << "migratePrefix - replaced empty with " << mOldPrefix << endl;
+ kdDebug(5006) << "migratePrefix - tqreplaced empty with " << mOldPrefix << endl;
msg += i18n("The configuration was automatically migrated but you should check "
"your account configuration.");
} else if ( list.count() == 1 ) {
- // only one entry in the personal namespace so replace it
+ // only one entry in the personal namespace so tqreplace it
TQString old = list.first();
list.clear();
list += mOldPrefix;
mNamespaces[PersonalNS] = list;
- if ( mNamespaceToDelimiter.contains( old ) ) {
+ if ( mNamespaceToDelimiter.tqcontains( old ) ) {
TQString delim = mNamespaceToDelimiter[old];
mNamespaceToDelimiter.remove( old );
mNamespaceToDelimiter[mOldPrefix] = delim;
}
- kdDebug(5006) << "migratePrefix - replaced single with " << mOldPrefix << endl;
+ kdDebug(5006) << "migratePrefix - tqreplaced single with " << mOldPrefix << endl;
msg += i18n("The configuration was automatically migrated but you should check "
"your account configuration.");
} else {
@@ -812,7 +812,7 @@ namespace KMail {
{
//kdDebug(5006) << "delimiterForNamespace " << prefix << endl;
// try to match exactly
- if ( mNamespaceToDelimiter.contains(prefix) ) {
+ if ( mNamespaceToDelimiter.tqcontains(prefix) ) {
return mNamespaceToDelimiter[prefix];
}
@@ -820,17 +820,17 @@ namespace KMail {
// exclude empty namespace
for ( namespaceDelim::ConstIterator it = mNamespaceToDelimiter.begin();
it != mNamespaceToDelimiter.end(); ++it ) {
// the namespace definition sometimes contains the delimiter
// make sure we also match this version
TQString stripped = it.key().left( it.key().length() - 1 );
if ( !it.key().isEmpty() &&
- ( prefix.contains( it.key() ) || prefix.contains( stripped ) ) ) {
+ ( prefix.tqcontains( it.key() ) || prefix.tqcontains( stripped ) ) ) {
return it.data();
}
}
// see if we have an empty namespace
// this should always be the case
- if ( mNamespaceToDelimiter.contains( "" ) ) {
+ if ( mNamespaceToDelimiter.tqcontains( "" ) ) {
return mNamespaceToDelimiter[""];
}
// well, we tried
@@ -961,10 +961,10 @@ namespace KMail {
KMessageBox::information( kapp->activeWindow(), msg, caption, "kmailConnectionBrokenErrorDialog" );
// Show it in the status bar, in case the user has ticked "don't show again"
if ( errorCode == KIO::ERR_CONNECTION_BROKEN )
- KPIM::BroadcastStatus::instance()->setStatusMsg(
+ KPIM::BroadcasStatus::instance()->seStatusMsg(
i18n( "The connection to account %1 was broken." ).arg( name() ) );
else if ( errorCode == KIO::ERR_SERVER_TIMEOUT )
- KPIM::BroadcastStatus::instance()->setStatusMsg(
+ KPIM::BroadcasStatus::instance()->seStatusMsg(
i18n( "The connection to account %1 timed out." ).arg( name() ) );
} else {
if ( !errors.isEmpty() )
@@ -1025,7 +1025,7 @@ namespace KMail {
//-----------------------------------------------------------------------------
void ImapAccountBase::processNewMailInFolder( KMFolder* folder, FolderListType type /*= Single*/ )
{
- if ( mFoldersQueuedForChecking.contains( folder ) )
+ if ( mFoldersQueuedForChecking.tqcontains( folder ) )
return;
mFoldersQueuedForChecking.append( folder );
mCheckingSingleFolder = ( type == Single );
@@ -1057,7 +1057,7 @@ namespace KMail {
//-----------------------------------------------------------------------------
bool ImapAccountBase::checkingMail( KMFolder *folder )
{
- if (checkingMail() && mFoldersQueuedForChecking.contains(folder))
+ if (checkingMail() && mFoldersQueuedForChecking.tqcontains(folder))
return true;
return false;
}
@@ -1215,7 +1215,7 @@ namespace KMail {
jd.path = path;
insertJob(job, jd);
connect(job, TQT_SIGNAL(result(KIO::Job *)),
- TQT_SLOT(slotSetStatusResult(KIO::Job *)));
+ TQT_SLOT(slotSeStatusResult(KIO::Job *)));
}
void ImapAccountBase::setImapSeenStatus(KMFolder * folder, const TQString & path, bool seen)
@@ -1237,11 +1237,11 @@ namespace KMail {
jd.path = path;
insertJob(job, jd);
connect(job, TQT_SIGNAL(result(KIO::Job *)),
- TQT_SLOT(slotSetStatusResult(KIO::Job *)));
+ TQT_SLOT(slotSeStatusResult(KIO::Job *)));
}
//-----------------------------------------------------------------------------
- void ImapAccountBase::slotSetStatusResult(KIO::Job * job)
+ void ImapAccountBase::slotSeStatusResult(KIO::Job * job)
{
ImapAccountBase::JobIterator it = findJob(job);
if ( it == jobsEnd() ) return;
@@ -820,17 +820,17 @@ namespace KMail {
for ( namespaceDelim::ConstIterator it = mNamespaceToDelimiter.begin();
it != mNamespaceToDelimiter.end(); ++it ) {
- // the namespace definition sometimes contains the delimiter
+ // the namespace definition sometimes tqcontains the delimiter
// make sure we also match this version
TQString stripped = it.key().left( it.key().length() - 1 );